@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.25  Copyright Tobias Oetiker, 1997, 1998, 1999
+ * RRDtool 1.0.28  Copyright Tobias Oetiker, 1997, 1998, 1999
  *****************************************************************************
  * rrd_format.h  RRD Database Format header
  *****************************************************************************/
@@ -171,8 +171,8 @@ enum cf_en           { CF_AVERAGE=0,     /* data consolidation functions */
                        CF_LAST};
 
 enum rra_par_en {   RRA_cdp_xff_val=0};   /* what part of the consolidated 
-					    datapoint must be known, to produce a
-					    valid entry in the rra */
+					    datapoint may be unknown, while 
+					    still a valid entry in goes into the rra */
 		   	
 #define CF_NAM_FMT    "%19[A-Z]"
 #define CF_NAM_SIZE   20
