@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.25  Copyright Tobias Oetiker, 1997 - 2000
+ * RRDtool 1.0.28  Copyright Tobias Oetiker, 1997 - 2000
  *****************************************************************************
  * rrd_info  Get Information about the configuration of an RRD
  *****************************************************************************/
@@ -114,9 +114,15 @@ rrd_info(int argc, char **argv) {
 	info.u_str=rrd.rra_def[i].cf_nam;
 	cd=push(cd,sprintf_alloc("rra[%d].cf",         i),  RD_I_STR,   info);
 
+	info.u_cnt=rrd.rra_def[i].row_cnt;
+	cd=push(cd,sprintf_alloc("rra[%d].rows",i),  RD_I_CNT,   info);
+
 	info.u_cnt=rrd.rra_def[i].pdp_cnt;
 	cd=push(cd,sprintf_alloc("rra[%d].pdp_per_row",i),  RD_I_CNT,   info);
 
+        info.u_val=rrd.rra_def[i].par[RRA_cdp_xff_val].u_val;
+        cd=push(cd,sprintf_alloc("rra[%d].xff",i),  RD_I_VAL,   info);
+        
 	for(ii=0;ii<rrd.stat_head->ds_cnt;ii++){
 	    info.u_val=rrd.cdp_prep[i*rrd.stat_head->ds_cnt+ii].scratch[CDP_val].u_val;
 	    cd=push(cd,sprintf_alloc("rra[%d].cdp_prep[%d].value",i,ii), RD_I_VAL, info);
@@ -125,6 +131,7 @@ rrd_info(int argc, char **argv) {
 	    cd=push(cd,sprintf_alloc("rra[%d].cdp_prep[%d].unknown_datapoints",i,ii), RD_I_CNT, info);
         }
     }
+    rrd_free(&rrd);
     return(data);
 
 }
